@@ -44,14 +44,14 @@ void SearchexpansionFilter::filterMessage(KTp::Message &message, const KTp::Mess
     Q_UNUSED(context);
 }
 
-void SearchexpansionFilter::filterOutgoingMessage(KTp::Message &message, const KTp::MessageContext &context)
+void SearchexpansionFilter::filterOutgoingMessage(KTp::OutgoingMessage &message, const KTp::MessageContext &context)
 {
     Q_UNUSED(context);
-    KUriFilterData data(message.mainMessagePart().trimmed());
+    KUriFilterData data(message.text().trimmed());
     if(KUriFilter::self()->filterSearchUri(data, KUriFilter::WebShortcutFilter)) {
 
 //         kDebug() << "Succesfully filtered" << data.typedString() << "to" << data.uri();
-        message.setMainMessagePart(data.uri().url());
+        message.setText(data.uri().url());
     }
 }
 
